@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: persistent
 version: 2.2.4
-id: persistent-2.2.4-7522deb7fd39c262180984fc189631e9
-key: persi_5ADFnEQwbUn7KjyX4rJFOV
+id: persistent-2.2.4-3efd0b27ba9bd4f18bae3621104638b2
+key: persi_BQQo7srMDvZ00yx781ZnQ2
 license: MIT
 maintainer: Michael Snoyman <michael@snoyman.com>, Greg Weber <greg@gregweber.info>
 stability: Stable
@@ -35,38 +35,38 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/persistent-2.2.4
 library-dirs: /usr/lib/ghc-7.10.3/site-local/persistent-2.2.4
 data-dir: /usr/share/arm-linux-ghc-7.10.3/persistent-2.2.4
-hs-libraries: HSpersistent-2.2.4-5ADFnEQwbUn7KjyX4rJFOV
+hs-libraries: HSpersistent-2.2.4-BQQo7srMDvZ00yx781ZnQ2
 depends:
-    aeson-0.10.0.0-b63a88a6e7bf231c11601ff561c0eb0d
-    attoparsec-0.13.0.1-57451b44323b331c08be1b712bdc3810
+    aeson-0.10.0.0-d37842f030fec47bc6e0ba2aef0f6571
+    attoparsec-0.13.0.1-cc18275e376dae94cc21e54b8b072afd
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
     base64-bytestring-1.0.0.1-7819850819049320f81b6417431cc8a5
-    blaze-html-0.8.1.1-b598557be4ce3598e270c7592be1f33c
-    blaze-markup-0.7.0.3-adfaa12a6c8f95338d1eda4a379eb541
+    blaze-html-0.8.1.1-59ea4b5f01886f370857b4d16361c2fc
+    blaze-markup-0.7.0.3-4e4a97653c712eed9984271000636729
     bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
-    conduit-1.2.6.1-99a58e37479a2070047844a872c4445f
+    conduit-1.2.6.1-20c379c1e33e978c5d5c8f5ef78dd0c3
     containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
     exceptions-0.8.2.1-8c1fe53cd5846ab1f6d4c58870c4f8d9
-    fast-logger-2.4.1-3a82ef8da5665c7f13125a65809925c9
-    http-api-data-0.2.2-d3c9f175f1f98718629e761de86ea99f
-    lifted-base-0.2.3.6-d9ded25fdcc56319fed7ad1fd7194bcc
-    monad-control-1.0.0.4-fa18b603f1c859e06ea8fbebdf00a3e7
-    monad-logger-0.3.17-6bebcabc98fb90582d59aab2ac8cf400
+    fast-logger-2.4.1-72875ca91290e61690089a3e7f5d8466
+    http-api-data-0.2.2-107631c0bae2e2a6211651e9a27c130c
+    lifted-base-0.2.3.6-26b5b3c50c56a653ba3c5b8bce492107
+    monad-control-1.0.0.5-237b0aabd7893e5e3f4b9224e05c849c
+    monad-logger-0.3.18-2bfbe07c1c1cdc537fa81b345cec7330
     mtl-2.2.1-c516313407bc17046965067cb7cbb6a0
     old-locale-1.0.0.7-5aedb410aa2e5fddd3c57e9b4de1f46a
-    path-pieces-0.2.1-1993cf7409b1066d7297872970b0fe71
-    resource-pool-0.2.3.2-bd63600cbb4b1187bb6a3c1ed6e4569b
-    resourcet-1.1.7-7e93b08fc7a9dc3281fd76904261e146
-    scientific-0.3.4.4-2c552cd0c6d8817341c76144fa370151
+    path-pieces-0.2.1-c4c6ea4593a7da7123f92fac6c85ebd3
+    resource-pool-0.2.3.2-43a43754061092f307f80bb6d2ee434f
+    resourcet-1.1.7.1-34b9e931a3d19e984bea5de562a18bbd
+    scientific-0.3.4.4-3faa9d36abc45b55aed128d427a02fce
     silently-1.2.5-7f926db5f44f7696c1a8c4ab976d4845
-    tagged-0.8.2-849e3b2865ae1877e32ec9d4d01c3d0a
+    tagged-0.8.3-aa128de4449752177a05765fb0ce3959
     template-haskell-2.10.0.0-4b92ab565139fd81021b60a162b59eb8
-    text-1.2.1.3-6c3c87c392cdf2c29fca1c10bbf7250b
+    text-1.2.2.0-2f82ea4adfdd656d9a8840ad2ee17cc0
     time-1.5.0.1-cf94b0d806e26f6c4e356671290061b2
     transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
     transformers-base-0.4.4-b65bc998c24abf50fea29d4891da9e32
-    unordered-containers-0.2.6.0-08e36bb27daebf8e082345cc5a0772e7
-    vector-0.11.0.0-c9b9eff80d809aeb097685ce86af03c4
+    unordered-containers-0.2.6.0-2907cc2989779dea3b04f8a0a144a8a7
+    vector-0.11.0.0-711d35c4a6ac1ea2e529dc3ee3328963
 haddock-interfaces: /usr/share/doc/haskell-persistent/html/persistent.haddock
 haddock-html: /usr/share/doc/haskell-persistent/html
 ' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
